summaryrefslogtreecommitdiffstats
path: root/kaddressbook/printing/kabentrypainter.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
commit4c6f8d69e2d1501837affb472c4eb8fec4462240 (patch)
tree766a8ad7939fcf3eec534184c36bd0e0f80489e2 /kaddressbook/printing/kabentrypainter.cpp
parent469cc56a805bd3d6940d54adbef554877c29853c (diff)
downloadtdepim-4c6f8d69e2d1501837affb472c4eb8fec4462240.tar.gz
tdepim-4c6f8d69e2d1501837affb472c4eb8fec4462240.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246075 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kaddressbook/printing/kabentrypainter.cpp')
-rw-r--r--kaddressbook/printing/kabentrypainter.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kaddressbook/printing/kabentrypainter.cpp b/kaddressbook/printing/kabentrypainter.cpp
index 356b53dfb..91bf9f342 100644
--- a/kaddressbook/printing/kabentrypainter.cpp
+++ b/kaddressbook/printing/kabentrypainter.cpp
@@ -139,7 +139,7 @@ int KABEntryPainter::hits( const TQRectList& list, const TQPoint &p )
int count = 0;
for ( pos = list.begin(); pos != list.end(); ++pos ) {
- if ( (*pos).tqcontains( p ) )
+ if ( (*pos).contains( p ) )
return count;
++count;
@@ -241,7 +241,7 @@ bool KABEntryPainter::printAddressee( const KABC::Addressee &addr,
if ( !( addr.prefix().isEmpty() ) )
y += fmBody.lineSpacing() / 2;
// fill the parts stringlist, it tqcontains "parts" (printable areas)
// that will be combined to fill the page as effectively as possible:
// Email addresses:
if ( !addr.emails().isEmpty() && mShowEmails ) {
@@ -241,7 +241,7 @@ bool KABEntryPainter::printAddressee( const KABC::Addressee &addr,
if ( !( addr.prefix().isEmpty() ) )
y += fmBody.lineSpacing() / 2;
- // fill the parts stringlist, it tqcontains "parts" (printable areas)
+ // fill the parts stringlist, it contains "parts" (printable areas)
// that will be combined to fill the page as effectively as possible:
// Email addresses: